pub fn replace_exec_event_sender(sender: UnboundedSender<ExecutionEvent>)Expand description
Replaces the global execution event sender for the current thread.
pub fn replace_exec_event_sender(sender: UnboundedSender<ExecutionEvent>)Replaces the global execution event sender for the current thread.