pub fn replace_system_command_sender(sender: UnboundedSender<SystemCommand>)Expand description
Replaces the global system command sender for the current thread.
pub fn replace_system_command_sender(sender: UnboundedSender<SystemCommand>)Replaces the global system command sender for the current thread.