pub fn replace_system_event_sender(sender: UnboundedSender<SystemEvent>)Expand description
Replaces the global system event sender for the current thread.
pub fn replace_system_event_sender(sender: UnboundedSender<SystemEvent>)Replaces the global system event sender for the current thread.