pub fn try_get_system_command_sender() -> Option<UnboundedSender<SystemCommand>>Expand description
Attempts to get the global system command sender without panicking.
Returns None if the sender is not initialized.
pub fn try_get_system_command_sender() -> Option<UnboundedSender<SystemCommand>>Attempts to get the global system command sender without panicking.
Returns None if the sender is not initialized.