pub fn try_get_system_event_sender() -> Option<UnboundedSender<SystemEvent>>Expand description
Attempts to get the global system event sender without panicking.
Returns None if the sender is not initialized (e.g., in test environments).
pub fn try_get_system_event_sender() -> Option<UnboundedSender<SystemEvent>>Attempts to get the global system event sender without panicking.
Returns None if the sender is not initialized (e.g., in test environments).