pub fn try_get_exec_event_sender() -> Option<UnboundedSender<ExecutionEvent>>Expand description
Attempts to get the global execution event sender without panicking.
Returns None if the sender is not initialized (e.g., in test environments).
pub fn try_get_exec_event_sender() -> Option<UnboundedSender<ExecutionEvent>>Attempts to get the global execution event sender without panicking.
Returns None if the sender is not initialized (e.g., in test environments).